declare module "ride-components-react" {}

declare module "ride-components-react/components" {}

declare module "ride-components-react/components/app" {
  export * from "ride-components-react/components/app/app";
  export * from "ride-components-react/components/app/aside";
  export * from "ride-components-react/components/app/content";
  export * from "ride-components-react/components/app/title";
  export * from "ride-components-react/components/app/toolbar";
}

declare module "ride-components-react/components/app/app" {
  import * as React from 'react';

  export interface IAppProperties {
    /**
     * aside component
     */
    aside?: any;
    /**
     * aside component colour
     * @type {string}
     */
    asideColor?: string;
    /**
     * aside title
     * @type {string}
     */
    asideTitle?: string;
    /**
     * aside title color
     * @type {string}
     */
    asideTitleColor?: string;
    /**
     * content component
     */
    content?: any;
    /**
     * content colour
     * @type {string}
     */
    contentColor?: string;
    /**
     * content title
     * @type {string}
     */
    contentTitle?: string;
    /**
     * toolbar component content
     * @type {string}
     */
    contentToolbar?: any;
    /**
     * toolbar color
     * @type {string}
     */
    contentToolbarColor?: string;
  }

  export class App extends React.Component<IAppProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/app/aside" {
  import * as React from 'react';

  export interface IAppAsideProperties {
    /**
     * app aside color
     * @type {string}
     */
    color?: string;
    /**
     * app aside title
     * @type {string}
     */
    title?: string;
    /**
     * app aside title color
     * @type {string}
     */
    titleColor?: string;
  }

  export class AppAside extends React.Component<IAppAsideProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/app/content" {
  import * as React from 'react';

  export interface IAppContentProperties {
    /**
     * app content color
     * @type {string}
     */
    color?: string;
    /**
     * app content title
     * @type {string}
     */
    title?: string;
    /**
     * app content toolbar component content
     * @type {string}
     */
    toolbar?: any;
    /**
     * app content toolbar component color
     * @type {string}
     */
    toolbarColor?: string;
  }

  export class AppContent extends React.Component<IAppContentProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/app/title" {
  import * as React from 'react';

  export interface IAppAsideTitleProperties {
    /**
     * app aside title color
     * @type {string}
     */
    color?: string;
  }

  export class AppAsideTitle extends React.Component<IAppAsideTitleProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/app/toolbar" {
  import * as React from 'react';

  export interface IToolbarItemProperties { }

  export class ToolbarItem extends React.Component<IToolbarItemProperties, any> {
    public render();
  }
}

declare module "ride-components-react/components/baloons/baloon" {
  import * as React from 'react';

  export interface IBaloonProps {
    /**
     * additional css classes
     */
    className?: string;
    /**
     * baloon header/arrow colour
     */
    color?: string;
    /**
     * baloon direction
     * 		bottom: the baloon will appear from bottom
     * 		top: the baloon will appear from top
     */
    direction?: string;
    /**
     * baloon title
     */
    title?: string;
    /**
     * flags if the baloon is visible or not
     */
    visible?: boolean;
  }

  interface IBaloonState {}

  export class Baloon extends React.Component<IBaloonProps, IBaloonState> {
    public render();
  }
}

declare module "ride-components-react/components/buttons/button" {
  import * as React from 'react';

  export interface IButtonProps {
    /**
     * if set to true, the button will span the full width of it's own container element
     * @type {boolean}
     */
    block?: boolean;
    /**
     * you can add every css class you want
     * @type {string}
     */
    className?: string;
    /**
     * This will add the related css colour class
     * 	available colours:
     * 		black
     *     blue
     *     gray
     *     green
     *     orange
     *     purple
     *     red
     *     white
     *     yellow
     * @type {string}
     */
    color?: string;
    /**
     * if set to true, the button will be hollow
     * @type {boolean}
     */
    hollow?: boolean;
    /**
     * if provided, the css button will have a glyphicon element with the provided className
     * @type {string}
     */
    icon?: string;
    /**
     * the onClick callback event
     * @type {any}
     */
    onClick?: any;
    /**
     * the onTouchEnd callback event
     * @type {any}
     */
    onTouchEnd?: any;
    /**
     * the onTouchStart callback event
     * @type {any}
     */
    onTouchStart?: any;
    /**
     * this will add a btn--rounded css class
     */
    rounded?: boolean;
    /**
     * button's title
     * @type {string}
     */
    title?: string;
  }

  export class Button extends React.Component<IButtonProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/buttons/list" {
  import * as React from 'react';

  import * as button from 'ride-components-react/components/buttons/button';
  import * as list from 'ride-components-react/components/lists/list';

  export interface IButtonListItemProps extends button.IButtonProps {
    current?: string;
  }

  export class ButtonListItem extends React.Component<IButtonListItemProps, {}> {
    public render();
  }

  export class ButtonList extends React.Component<list.IListProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/cards/card" {
  import * as React from 'react';

  export interface ICardHeaderProps {
    /**
     * card header color
     * @type {string}
     */
    color?: string;
    /**
     * card header additional css classname
     * @type {string}
     */
    className?: string;
    /**
     * card header background image path
     * @type {string}
     */
    image?: string;
    /**
     * sets the card header as tall.
     *  It is useful when applying large background images or to display cards
     *  in applications like Instagram
     * @type {string}
     */
    tall?: boolean;
  }

  export interface ICardProps {
    /**
     * you can add a React.Component after the content
     */
    afterContent?: any;
    /**
     * you can add a React.Component before the content
     */
    beforeContent?: any;
    /**
     * card's header colour
     */
    color?: string;
    /**
     * footer content. Pass a React.Component
     */
    footer?: any;
    /**
     * if set to true, the header will not display at all
     */
    hideHeader?: boolean;
    /**
     * You can add some css classes to the header
     * @type {string}
     */
    headerClassName?: string;
    /**
     * Header backgroundImage src
     * @type {string}
     */
    headerImage?: string;
    /**
     * if set to true, the header will be higher than normal
     */
    headerTall?: boolean;
    /**
     * header text
     */
    title?: string;
  }

  export class CardHeader extends React.Component<ICardHeaderProps, {}> {
    public render();
  }

  export class Card extends React.Component<ICardProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/dialog/dialog" {
  import * as React from 'react';

  export interface IDialogProps {
    /**
     * close icon css
     */
    closeIcon?: string;
    /**
     * dialog's header css
     */
    colour?: string;
    /**
     * if set to true, the dialog will occupy the entire screen
     */
    fullSize?: boolean;
    /**
     * Pass a React.Component to the Dialog Footer
     */
    footer?: any;
    /**
     * Dialog's position
     *  available positions are
     *    bottom
     *    center
     *    top
     * @type {string}
     */
    position: string;
    /**
     * Dialog header's title
     * @type {string}
     */
    title: string;
    /**
     * If set to true, the dialog will be visible
     */
    visible?: boolean;
  }

  export class Dialog extends React.Component<IDialogProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/dialog/dialog-overlay" {
  import * as React from 'react';

  export interface IDialogOverlayProps {
    /**
     * if set to true, the overlay will be visible
     * @type {boolean}
     */
    visible: boolean;
  }

  export class DialogOverlay extends React.Component<IDialogOverlayProps, any> {
    public render();
  }
}

declare module "ride-components-react/components/form" {
  export * from "ride-components-react/components/form/block";
  export * from "ride-components-react/components/form/checkbox";
  export * from "ride-components-react/components/form/range";
  export * from "ride-components-react/components/form/toggle";
}

declare module "ride-components-react/components/form/block" {
  import * as React from 'react';

  export class Block extends React.Component<{}, {}> {
    public render();
  }
}

declare module "ride-components-react/components/form/checkbox" {
  import * as React from 'react';

  export interface ICheckboxProperties {
    /**
     * if set to true, the Component will be checked
     * @optional
     */
    checked?: boolean;
    /**
     * Component colour
     * @optional
     */
    color?: string;
    /**
     * Triggered when the user changes the value (checked/unchecked)
     * @type {Function}
     */
    onChange: any;
    /**
     * HTML name attribute
     * @optional
     */
    name?: string;
    /**
     * HTML type attribute
     *  you can choose between checkbox and radio.
     *  default: checkbox
     * @optional
     */
    type?: string;
    /**
     * Value passed to the onChange callback if not checked
     * @optional
     */
    valueFalse?: any;
    /**
     * Value passed to the onChange callback if checked
     * @optional
     */
    valueTrue?: any;
  }

  export class Checkbox extends React.Component<ICheckboxProperties, {}> {
    public render();
  }

  export class Radio extends Checkbox { }
}

declare module "ride-components-react/components/form/range" {
  import * as React from 'react';

  export interface IFormRangeProps {
    /**
     * range bar here
     */
    color?: string;
    /**
     * the maximum value allowed
     *  default: 100
     */
    max?: number;
    /**
     * the minimum value allowed
     *  default: 0
     */
    min?: number;
    /**
     * Invokes a callback when the user changes the value of the range input.
     * @type {Function}
     */
    onChange?: any;
    /**
     * the step html attribute
     *  default: 1
     */
    step?: number;
    /**
     * The default value
     */
    value?: number;
  }

  export interface IFormRangeState { }

  export class Range extends React.Component<IFormRangeProps, IFormRangeState> {
    public render();
  }
}

declare module "ride-components-react/components/form/toggle" {
  import * as React from 'react';

  export interface IToggleProps {
    /**
     * if set to true, the toggle will be on
     *  default: false
     * @type {boolean}
     */
    checked?: boolean;
    /**
     * Toggle's on background colour
     *  default: 'blue'
     * @type {string}
     */
    color?: string;
    /**
     * A callback invoked when the user toggles on/off
     * @type {Function}
     */
    onChange?: any;
  }

  export class Toggle extends React.Component<IToggleProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/layout/col" {
  import * as React from 'react';

  export interface IColProps {
    /**
     * additional css
     * @type {string}
     */
    className?: string;
    /**
     * the column offset property
     *  you can set a negative or positive value in each breakpoint
     * @type {IColBreakpoints}
     */
    offset?: IColBreakpoints;
    /**
     * the column move property
     *  you can set a negative or positive value in each breakpoint
     * @type {IColBreakpoints}
     */
    move?: IColBreakpoints;
    /**
     * the column width property
     * @type {IColBreakpoints}
     */
    width?: IColBreakpoints;
  }

  export interface IColBreakpoints {
    /**
     * Depending on ride-components xs breakpoint
     * @type {number}
     */
    xs?: number;
    /**
     * Depending on ride-components sm breakpoint
     * @type {number}
     */
    sm?: number;
    /**
     * Depending on ride-components md breakpoint
     * @type {number}
     */
    md?: number;
    /**
     * Depending on ride-components lg breakpoint
     * @type {number}
     */
    lg?: number;
    /**
     * Depending on ride-components xl breakpoint
     * @type {number}
     */
    xl?: number;
  }

  export class Col extends React.Component<IColProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/layout/row" {
  import * as React from 'react';

  export interface IRowProps {

  }

  export class Row extends React.Component<IRowProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/layout/wrapper" {
  import * as React from 'react';

  export interface IWrapperProps {
    /**
     * wrapper's size
     *  available sizes:
     *    'tight'
     *    'wide'
     *    'wrapper'
     * @type {string}
     */
    size?: string;
  }

  export class Wrapper extends React.Component<IWrapperProps, any> {
    public render();
  }
}

declare module "ride-components-react/components/lists/list" {
  import * as React from 'react';

  export interface IListItemProperties {
    /**
     * if set to true, the list item will be marked as current
     * @type {boolean}
     */
    current?: boolean;
    /**
     * additional className
     * @type {string}
     */
    className?: string;
    /**
     * if set to true, the element will be hidden
     *  default: false
     * @type {boolean}
     */
    hidden?: boolean;
  }

  export interface IListProperties {
    /**
     * additional css className
     * @type {string}
     */
    className?: string;
    /**
     * if set to true, the Component will be hidden
     *  default: false
     */
    hidden?: boolean;
    /**
     * if set to true, the list will be indented
     *  default: false
     */
    indented?: boolean;
    /**
     * if set to true, the list will not have padding
     *  default: false
     */
    unpadded?: boolean;
    /**
     * if set to true, the list will be vertical
     *  default: false
     */
    vertical?: boolean;
  }

  export class ListItem extends React.Component<IListItemProperties, any> {
    public render();
  }

  export class List extends React.Component<IListProperties, {}> {
    public render();
  }
}

declare module "ride-components-react/components/notifications/alert" {
  import * as React from 'react';

  export interface IAlertProps { }

  export class Alert extends React.Component<IAlertProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/notifications/notification" {
  import * as React from 'react';

  export interface INotificationProperties extends INotificationState {
    /**
     * sets the colour for the Notification component
     * @type {string}
     */
    color?: string;
    /**
     * if set to true, the notification will be hollow.
     *  default: false
     * @type {boolean}
     */
    hollow?: boolean;
    /**
     * if set to true, the notification will be rounded
     *  default: false
     * @type {boolean}
     */
    rounded?: boolean;
  }

  export interface INotificationState {
    /**
     * if set to true, the notification will be visible
     */
    visible?: boolean;
  }

  export class Notification extends React.Component<INotificationProperties, INotificationState> {
    public render();
  }
}

declare module "ride-components-react/components/notifications/popup" {
  import * as React from 'react';

  export interface IPopupProps {
    /**
     * the popup colour
     *  default: blue
     * @type {string}
     */
    color?: string;
    /**
     * if set to true, the popup will be modal
     *  @type {boolean}
     */
    modal?: boolean;
    /**
     * if set to true, the popup will be rounded
     *  @type {boolean}
     */
    rounded?: boolean;
    /**
     * sets the text for the popup
     */
    text?: string;
    /**
    * if set to true, the popup will be visible
    *  @type {boolean}
    */
    visible?: boolean;
  }

  export class Popup extends React.Component<IPopupProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/notifications/push-notifications" {
  import * as React from 'react';

  export interface IPushNotificationsProps {
    /**
     * the position for the popup
     */
    position?: string;
    /**
     * Adds styles to the component
     */
    style?: React.CSSProperties;
  }

  export class PushNotifications extends React.Component<IPushNotificationsProps, any> {
    public render();
  }
}

declare module "ride-components-react/components/tabs/tabs" {
  import * as React from 'react';

  export interface ITabsProps {
    /**
     * buttons colours
     * @type {string}
     */
    buttonColor?: string;
    /**
     * active button colour
     * @type {string}
     */
    buttonActiveColor?: string;
    /**
     * buttons list
     * @type {string[]}
     */
    buttons: Array<string>;
    /**
     * if set to true, the component will be hidden
     * @type {string}
     */
    hidden?: boolean;
    /**
     * if set to true, the matching button will be selected
     * @type {string}
     */
    selected?: string;
    /**
     * if set to true, the buttons will be displayed vertically
     * @type {string}
     */
    vertical?: boolean;
  }

  export interface ITabsState {
    /**
     * tells the component which tab is active (this string should match a button)
     * @type {string}
     */
    current: string;
  }

  export class Tabs extends React.Component<ITabsProps, ITabsState> {
    public render();
  }
}

declare module "ride-components-react/components/user/image" {
  import * as React from 'react';

  export interface IUserImageProps {
    /**
     * tells the component if the image must be large or small
     */
    large?: boolean;
    /**
     * the path to the image
     * @type {string}
     */
    src: string;
  }

  export class UserImage extends React.Component<IUserImageProps, {}> {
    public render();
  }
}

declare module "ride-components-react/components/user/user" {
  import * as React from 'react';

  export interface IUser {
    vSpace?: boolean;
  }

  export class User extends React.Component<IUser, {}> {
    public render();
  }
}

declare module "ride-components-react/ui" {
  export * from "ride-components-react/components/baloons/baloon";
  export * from "ride-components-react/components/buttons/button";
  export * from "ride-components-react/components/buttons/list";
  export * from "ride-components-react/components/dialog/dialog";
  export * from "ride-components-react/components/dialog/dialog-overlay";
  export * from "ride-components-react/components/cards/card";
  export * from "ride-components-react/components/layout/col";
  export * from "ride-components-react/components/layout/row";
  export * from "ride-components-react/components/layout/wrapper";
  export * from "ride-components-react/components/lists/list";
  export * from "ride-components-react/components/notifications/notification";
  export * from "ride-components-react/components/notifications/popup";
  export * from "ride-components-react/components/notifications/push-notifications";
  export * from "ride-components-react/components/tabs/tabs";
  export * from "ride-components-react/components/user/image";
  export * from "ride-components-react/components/user/user";
}

/**
 * Utilities
 */
declare module "ride-components-react/utilities/css" {
  export class CssClassList {
    public add(className: string): CssClassList;
    public has(className: string): boolean;
    public remove(className: string): CssClassList;
    public toggle(className: string): CssClassList;
    public toString(): string;
  }
}

declare module "ride-components-react/utilities/dom" {
  export function get(selector: string): Element;
  export function getAll(selector: string): Array<Element>;
  export function ready(callback: any): void;
  export function renderComponent(component: any, target: string): Function;
}

declare module "ride-components-react/utilities/store" {
  export class Store<TStore> {
    private _data: TStore;
    private _history: Array<TStore>;
    private _initial: TStore;

    constructor(data: TStore);

    private _store(): void;
    private _storeRollback(): void;
    private _update(data: TStore);

    public clone(): Store<TStore>;
    public get(): TStore;
    public reset(): void;
    public rollback(): void;
    public update(data: TStore);
    public updateStrict(data: TStore);
  }
}

declare module "ride-components-react/utilities/string" {
  export function capitalizeFirst(inputString: string): string;
}
